@@ -1,28 +1,23 @@
-//============================================================================
-//
-// Terence Welsh Screensaver - Solar Winds
-// http://www.reallyslick.com/
-//
-// Ported to KDE by Karl Robillard
-//
 /*
- * Copyright (C) 2002  Terence M. Welsh
+ *  Terence Welsh Screensaver - Solar Winds
+ *  http://www.reallyslick.com/
  *
- * Solar Winds is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
- * published by the Free Software Foundation.
+ *  Ported to KDE by Karl Robillard
+ *  Copyright (C) 2002  Terence M. Welsh
  *
- * Solar Winds is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ *  This program is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU General Public License as
+ *  published by the Free Software Foundation; either version 2 of 
+ *  the License, or (at your option) any later version.
+ *   
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *   
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-//============================================================================
-
 
 #include <stdio.h>
 #include <math.h>
@@ -310,8 +305,8 @@ void wind::update()
 //----------------------------------------------------------------------------
 
 
-SWindsWidget::SWindsWidget( QWidget* parent, const char* name )
-                      : QGLWidget(parent, name), _winds(0)
+SWindsWidget::SWindsWidget( QWidget* parent )
+                      : QGLWidget(parent), _winds(0)
 {
     setDefaults( Regular );
 
@@ -592,21 +587,31 @@ void SWindsWidget::setDefaults(int which)
 
 
 // libkscreensaver interface
-extern "C"
+class KSolarWindsSaverInterface : public KScreenSaverInterface
 {
-    KDE_EXPORT const char* kss_applicationName = "ksolarwinds.kss";
-    KDE_EXPORT const char* kss_description = I18N_NOOP( "Solar Winds" );
-    KDE_EXPORT const char* kss_version = "1.0";
 
-    KDE_EXPORT KScreenSaver* kss_create( WId id )
+
+public:
+    virtual KAboutData* aboutData() {
+        return new KAboutData( "ksolarwinds.kss", 0, ki18n( "Solar Winds" ), "1.0", ki18n( "Solar Winds" ) );
+    }
+
+
+    virtual KScreenSaver* create( WId id )
     {
         return new KSWindsScreenSaver( id );
     }
 
-    KDE_EXPORT QDialog* kss_setup()
+    virtual QDialog* setup()
     {
         return new KSWindsSetup;
     }
+};
+
+int main( int argc, char *argv[] )
+{
+    KSolarWindsSaverInterface kss;
+    return kScreenSaverMain( argc, argv, kss );
 }
 
 
@@ -642,10 +647,9 @@ static int filterRandom( int n )
 
 void KSWindsScreenSaver::readSettings()
 {
-    KConfig* config = KGlobal::config();
-    config->setGroup("Settings");
+    KConfigGroup config(KGlobal::config(), "Settings");
 
-    _mode = config->readNumEntry( "Mode", SWindsWidget::Regular );
+    _mode = config.readEntry( "Mode", (int)SWindsWidget::Regular );
     _flux->setDefaults( filterRandom(_mode) );
 }
 
@@ -683,12 +687,17 @@ static const char* defaultText[] =
 };
 
 
-KSWindsSetup::KSWindsSetup( QWidget* parent, const char* name )
-        : KDialogBase( parent, name, true, i18n( "Setup Solar Wind" ),
-          Ok|Cancel|Help, Ok, true )
+KSWindsSetup::KSWindsSetup( QWidget* parent )
+        : KDialog( parent)
 {
     setButtonText( Help, i18n( "A&bout" ) );
-    QWidget *main = makeMainWidget();
+	setButtons(Ok|Cancel|Help);
+	setDefaultButton(Ok);
+	setCaption(i18n( "Setup Solar Wind" ));
+	setModal(true);
+	showButtonSeparator(true);
+    QWidget *main = new QWidget(this);
+	setMainWidget(main);
 
     QHBoxLayout* top = new QHBoxLayout( main, 0, spacingHint() );
 
@@ -710,7 +719,7 @@ KSWindsSetup::KSWindsSetup( QWidget* parent, const char* name )
     QWidget* preview;
     preview = new QWidget( main );
     preview->setFixedSize( 220, 165 );
-    preview->setBackgroundColor( black );
+    preview->setBackgroundColor( Qt::black );
     preview->show();    // otherwise saver does not get correct size
     _saver = new KSWindsScreenSaver( preview->winId() );
     top->addWidget(preview);
@@ -718,6 +727,8 @@ KSWindsSetup::KSWindsSetup( QWidget* parent, const char* name )
     // Now that we have _saver...
     modeW->setCurrentItem( _saver->mode() );    // set before we connect
     connect( modeW, SIGNAL(activated(int)), _saver, SLOT(setMode(int)) );
+	connect( this, SIGNAL(okClicked()), this, SLOT(slotOk()));
+	connect( this, SIGNAL(helpClicked()),this,SLOT(slotHelp()));
 }
 
 
@@ -731,7 +742,7 @@ void KSWindsSetup::slotHelp()
 {
     KMessageBox::about(this,
         i18n("<h3>Solar Winds 1.0</h3>\n<p>Copyright (c) 2002 Terence M. Welsh<br>\n<a href=\"http://www.reallyslick.com/\">http://www.reallyslick.com/</a></p>\n\n<p>Ported to KDE by Karl Robillard</p>"),
-        QString::null, KMessageBox::AllowLink);
+        QString(), KMessageBox::AllowLink);
 }
 
 
@@ -740,14 +751,13 @@ void KSWindsSetup::slotHelp()
 */
 void KSWindsSetup::slotOk()
 {
-    KConfig* config = KGlobal::config();
-    config->setGroup("Settings");
+    KConfigGroup config(KGlobal::config(), "Settings");
 
     QString val;
     val.setNum( modeW->currentItem() );
-    config->writeEntry("Mode", val );
+    config.writeEntry("Mode", val );
 
-    config->sync();
+    config.sync();
     accept();
 }
 #endif
