@@ -363,12 +363,13 @@ void KBannerSetup::slotHelp()
 
 KBannerSaver::KBannerSaver( WId id ) : KScreenSaver( id )
 {
+	setBackgroundColor( Qt::black );
 	krnd = new KRandomSequence();
 	readSettings();
 	initialize();
-	needBlank = true;
 	timer.start( speed );
 	connect( &timer, SIGNAL( timeout() ), SLOT( slotTimeout() ) );
+	update();
 }
 
 KBannerSaver::~KBannerSaver()
@@ -415,14 +416,14 @@ void KBannerSaver::setMessage( const QString &msg )
     showTime = false;
     message = msg;
     pixmapSize = QSize();
-    needBlank = true;
+    setAttribute( Qt::WA_NoSystemBackground, false );
 }
 
 void KBannerSaver::setTimeDisplay()
 {
     showTime = true;
     pixmapSize = QSize();
-    needBlank = true;
+    setAttribute( Qt::WA_NoSystemBackground, false );
 }
 
 // read settings from config file
@@ -462,10 +463,10 @@ void KBannerSaver::initialize()
 	font = QFont( fontFamily, fsize, bold ? QFont::Bold : QFont::Normal, italic );
 
 	pixmapSize = QSize();
-	needBlank = true;
+	setAttribute( Qt::WA_NoSystemBackground, false );
 
 	xpos = width();
-	ypos = fsize + (int) ((double)(height()-fsize)*krnd->getDouble());
+	ypos = fsize + (int) ((double)(height() - 3 * fsize) * krnd->getDouble());
 	step = 2 * width() / QApplication::desktop()->width(); // 6 -> 2 -hhjb-
 	if ( step == 0 )
 		step = 1;
@@ -478,6 +479,8 @@ void KBannerSaver::slotTimeout()
 // erase old text and draw in new position
 void KBannerSaver::paintEvent(QPaintEvent *event)
 {
+    setAttribute( Qt::WA_NoSystemBackground ); // Only after requested clear is done
+
     if (cyclingColor)
     {
         int hueStep = speed/10;
@@ -491,7 +494,7 @@ void KBannerSaver::paintEvent(QPaintEvent *event)
 	    needUpdate = true;
 	message = new_message;
     }
-    if ( !pixmapSize.isValid() || cyclingColor || needUpdate || needBlank )
+    if ( !pixmapSize.isValid() || cyclingColor || needUpdate || !testAttribute( Qt::WA_NoSystemBackground ) )
     {
         QRect rect = QFontMetrics( font ).boundingRect( message );
 	rect.setWidth( rect.width() + step );
@@ -512,14 +515,8 @@ void KBannerSaver::paintEvent(QPaintEvent *event)
 	QPainter p( this );
 	p.fillRect( xpos + step, ypos, pixmapSize.width(), pixmapSize.height(), Qt::black );
 	xpos = width();
-	ypos = fsize + (int) ((double)(height()-2.0*fsize)*krnd->getDouble());
+	ypos = fsize + (int) ((double)(height() - 3 * fsize) * krnd->getDouble());
     }
 
-    if ( needBlank )
-    {
-	setBackgroundColor( Qt::black );
-	update();
-	needBlank = false;
-    }
     bitBlt( this, xpos, ypos, &pixmap, 0, 0, pixmapSize.width(), pixmapSize.height());
 }
